@@ -1,10 +1,11 @@
 use strict;
 use warnings;
 package Devel::DidYouMean;
-$Devel::DidYouMean::VERSION = '0.02';
+$Devel::DidYouMean::VERSION = '0.03';
 use feature 'say';
 use vars qw($AUTOLOAD);
 use Text::Levenshtein;
+use Perl::Builtins;
 use Carp 'croak';
 no warnings 'once';
 no strict qw/refs subs/;
@@ -16,263 +17,24 @@ no strict qw/refs subs/;
 
 our $DYM_MATCHING_SUBS = [];
 
-# add main
-*{ main::AUTOLOAD } = Devel::DidYouMean::AUTOLOAD;
+CHECK {
 
-# add to every other module !
-for (keys %INC)
-{
-    my $module = $_ =~ s/\//::/gr;
-    $module = substr($module, 0, -3);
+    # add autoload to main
+    *{ main::AUTOLOAD } = Devel::DidYouMean::AUTOLOAD;
 
-    next if $module eq __PACKAGE__;
+    # add to every other module in memory
+    for (keys %INC)
+    {
+        my $module = $_ =~ s/\//::/gr;
+        $module = substr($module, 0, -3);
 
-    $module .= '::AUTOLOAD';
-    *{ $module } = Devel::DidYouMean::AUTOLOAD;
+        next if $module eq __PACKAGE__;
+
+        $module .= '::AUTOLOAD';
+        *{ $module } = Devel::DidYouMean::AUTOLOAD;
+    }
 }
 
-my @functions = qw/AUTOLOAD
-abs
-accept
-alarm
-and
-atan2
-BEGIN
-bind
-binmode
-bless
-CHECK
-caller
-chdir
-chmod
-chomp
-chop
-chown
-chr
-chroot
-close
-closedir
-cmp
-connect
-continue
-crypt
-DESTROY
-__DATA__
-dbmclose
-dbmopen
-default
-defined
-delete
-die
-do
-dump
-END
-__END__
-each
-else
-elseif
-elsif
-endgrent
-endhostent
-endnetent
-endprotoent
-endpwent
-endservent
-eof
-eq
-eval
-evalbytes
-exec
-exists
-exit
-exp
-__FILE__
-fc
-fcntl
-fileno
-flock
-for
-foreach
-fork
-format
-formline
-ge
-getc
-getgrent
-getgrnam
-gethostbyaddr
-gethostbyname
-gethostent
-getnetbyaddr
-getnetbyname
-getnetent
-getpgrp
-getppid
-getpriority
-getprotobyname
-getprotobynumber
-getprotoent
-getpwent
-getpwnam
-getpwuid
-getservbyname
-getservbyport
-getservent
-getsockopt
-given
-glob
-gmtime
-goto
-grep
-gt
-hex
-INIT
-if
-import
-index
-int
-ioctl
-join
-keys
-kill
-__LINE__
-last
-lc
-lcfirst
-le
-length
-link
-listen
-localtime
-lock
-log
-lstat
-lt
-m
-map
-mkdir
-msgctl
-msgget
-msgrcv
-msgsnd
-my
-ne
-next
-no
-not
-oct
-open
-opendir
-or
-ord
-our
-__PACKAGE__
-pack
-package
-pipe
-pop
-pos
-print
-printf
-prototype
-push
-q
-qq
-qr
-qw
-qx
-rand
-readdir
-readline
-readlink
-readpipe
-recv
-redo
-ref
-rename
-require
-reset
-return
-reverse
-rewinddir
-rindex
-rmdir
-__SUB__
-s
-say
-scalar
-seek
-seekdir
-semctl
-semget
-semop
-send
-setgrent
-sethostent
-setnetent
-setpgrp
-setpriority
-setprotoent
-setpwent
-setservent
-setsockopt
-shift
-shmctl
-shmget
-shmread
-sin
-sleep
-socket
-socketpair
-sort
-split
-sprintf
-srand
-stat
-state
-study
-sub
-substr
-symlink
-syscall
-sysopen
-sysread
-sysseek
-system
-tell
-telldir
-tie
-time
-times
-tr
-truncate
-UNITCHECK
-uc
-ucfirst
-umask
-undef
-unless
-unlink
-unpack
-unshift
-untie
-until
-use
-utime
-values
-vec
-wait
-waitpid
-wantarray
-warn
-when
-while
-write
--X
-x
-xor
-y/;
-
 sub AUTOLOAD
 {
     my @sub_path = split /::/, $AUTOLOAD;
@@ -298,7 +60,7 @@ sub AUTOLOAD
     # if package is main, add in builtin functions
     if ($package eq 'main')
     {
-        for (@functions)
+        for (Perl::Builtins::list)
         {
             $valid_subs{$_} = Text::Levenshtein::fastdistance($sub, $_);
         }
@@ -336,30 +98,31 @@ Devel::DidYouMean - Intercepts failed function and method calls, suggesting the
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head2 SYNOPSIS
 
     #!/usr/bin/env perl
+
     # somescript.pl
     use Data::Dumper;
-    require Devel::DidYouMean;
+    use Devel::DidYouMean;
 
     print Dumpr($data); # wrong function name
-    ...
 
 *Run the code*
 
     $ somescript.pl
-    Undefined subroutine 'Dumpr' not found in main. Did you mean Dumper? at somescript.pl line 6.
+    Undefined subroutine 'Dumpr' not found in main. Did you mean Dumper? at somescript.pl line 7.
 
-Or add as a one liner:
+Or as a one liner:
 
-    $ perl -Ilib -mData::Dumper -MDevel::DidYouMean -e 'Data::Dumper::Dumpr($data)'
-    Undefined subroutine 'Dumpr' not found in Data::Dumper. Did you mean Dumper? at -e line 1.
+    $ perl -MData::Dumper -MDevel::DidYouMean -e 'print Dumpr($data)'
+    Undefined subroutine 'Dumpr' not found in main. Did you mean Dumper? at -e line 1.
 
-Maybe trap the error and extract the matching subs for something else
+Or trap the error and extract the matching subs
 
+    use Devel::DidYouMean;
     use Try::Tiny;
 
     try
@@ -370,7 +133,8 @@ Maybe trap the error and extract the matching subs for something else
     {
         my $error_msg = $_;
         my @closest_matching_subs = @$Devel::DidYouMean::DYM_MATCHING_SUBS;
-        ...
+
+        # do something cool here
     }
 
 =head2 DESCRIPTION
@@ -379,7 +143,7 @@ L<Devel::DidYouMean> intercepts failed function and method calls, suggesting the
 
 =head2 WARNING
 
-This library is experimental, on load it exports an AUTOLOAD subroutine to every namespace in the symbol table. Therefore it should be loaded last in your program, preferably using C<require>.
+This library is experimental, on load it exports an AUTOLOAD subroutine to every namespace in the symbol table. In version 0.03 and higher, this library must be loaded using C<use> and not C<require>.
 
 =head2 THANKS
 
